<?php

declare(strict_types=1);

namespace App\Entity;

use App\Enum\SystemSettingKey;
use App\Repository\SystemConfigRepository;
use DateTimeImmutable;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: SystemConfigRepository::class)]
#[ORM\Table(name: 'system_config')]
class SystemConfig
{
    public const string DEFAULT_STOCK_ADJUSTMENT_LOOKBACK_ORDERS = '3';
    public const string STOCK_ADJUSTMENT_LOOKBACK_ORDERS_DESCRIPTION = 'Number of orders to look back for stock adjustment';
    public const string DEFAULT_DEFAULT_WANTED_STOCK = '2';
    public const string DEFAULT_DEFAULT_WANTED_STOCK_DESCRIPTION = 'Default wanted stock for new drink types';
    public const string DEFAULT_SYSTEM_NAME = 'Zaufen';
    public const string DEFAULT_SYSTEM_NAME_DESCRIPTION = 'System name';
    public const string DEFAULT_STOCK_INCREASE_AMOUNT = '1';
    public const string DEFAULT_STOCK_INCREASE_AMOUNT_DESCRIPTION = 'Amount to increase stock by for stock adjustment suggested by the system';
    public const string DEFAULT_STOCK_DECREASE_AMOUNT = '1';
    public const string DEFAULT_STOCK_DECREASE_AMOUNT_DESCRIPTION = 'Amount to decrease stock by for stock adjustment suggested by the system';
    public const string DEFAULT_STOCK_LOW_MULTIPLIER = '0.3';
    public const string DEFAULT_STOCK_LOW_MULTIPLIER_DESCRIPTION = 'Multiplier to to check if stock is low.';

    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column(type: 'integer')]
    private null|int $id = null;

    #[ORM\Column(type: 'datetime_immutable')]
    private readonly DateTimeImmutable $createdAt;

    #[ORM\Column(type: 'datetime_immutable')]
    private DateTimeImmutable $updatedAt;

    #[ORM\Column(unique: true, enumType: SystemSettingKey::class)]
    private SystemSettingKey $key;

    #[ORM\Column(type: 'text')]
    private string $value;

    #[ORM\Column(type: 'text', options: [
        'default' => '',
    ])]
    private string $description;


    public function __construct(
    ) {
        $this->createdAt = new DateTimeImmutable();
        $this->updatedAt = new DateTimeImmutable();
    }

    public function getId(): null|int
    {
        return $this->id;
    }

    public function getKey(): SystemSettingKey
    {
        return $this->key;
    }

    public function setKey(SystemSettingKey $key): self
    {
        $this->key = $key;
        return $this;
    }

    public function getValue(): string
    {
        return $this->value;
    }

    public function setValue(string $value): self
    {
        $this->value = $value;
        return $this;
    }

    public function getCreatedAt(): DateTimeImmutable
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): DateTimeImmutable
    {
        return $this->updatedAt;
    }

    #[ORM\PrePersist]
    protected function updateTimestamp(): void
    {
        $this->updatedAt = new DateTimeImmutable();
    }

    public function getDescription(): string
    {
        return $this->description;
    }

    public function setDescription(string $description): void
    {
        $this->description = $description;
    }
}
