<?php

declare(strict_types=1);

namespace App\Form;

use App\Entity\DrinkType;
use App\Entity\OrderItem;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\IntegerType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\GreaterThan;
use Symfony\Component\Validator\Constraints\NotNull;

class OrderItemType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('drinkType', EntityType::class, [
                'class' => DrinkType::class,
                'choice_label' => 'name',
                'placeholder' => 'Select a drink type',
                'required' => true,
                'constraints' => [
                    new NotNull(message: 'Please select a drink type'),
                ],
            ])
            ->add('quantity', IntegerType::class, [
                'required' => true,
                'constraints' => [
                    new NotNull(message: 'Please enter a quantity'),
                    new GreaterThan(value: 0, message: 'Quantity must be greater than 0'),
                ],
            ]);
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => OrderItem::class,
        ]);
    }
}
